package com.loganmagnan.eventcore.menusystem.menus;

import com.loganmagnan.eventcore.EventCore;
import com.loganmagnan.eventcore.menusystem.ItemStackButton;
import com.loganmagnan.eventcore.menusystem.Menu;
import com.loganmagnan.eventcore.menusystem.PlayerMenuUtil;
import com.loganmagnan.eventcore.utils.ColorUtils;
import com.loganmagnan.eventcore.utils.Utils;
import org.bukkit.Material;
import org.bukkit.entity.Player;
import org.bukkit.event.inventory.InventoryClickEvent;
import org.bukkit.inventory.ItemStack;
import java.util.Arrays;

public class ChatManagementMenu extends Menu {

    private EventCore main = EventCore.getInstance();

    private int delayAmount = 0;

    public ChatManagementMenu(PlayerMenuUtil playerMenuUtil, int delayAmount) {
        super(playerMenuUtil);

        this.delayAmount = delayAmount;
    }

    @Override
    public String getMenuName() {
        return ColorUtils.getMessageType("&bChat Management");
    }

    @Override
    public int getSlots() {
        return 27;
    }

    @Override
    public void handleMenu(InventoryClickEvent event) {
        Player player = (Player) event.getWhoClicked();

        if (event.getView().getTitle().equalsIgnoreCase(ColorUtils.getMessageType("&bChat Management"))) {
            switch (event.getCurrentItem().getType()) {
                case DIAMOND_SWORD:
                    this.main.getChatManager().toggleChat(player);

                    break;
                case SOUL_SAND:
                    if (event.getClick().isLeftClick()) {
                        this.delayAmount++;

                        new ChatManagementMenu(this.playerMenuUtil, this.delayAmount).open(player);
                    } else if (event.getClick().isRightClick()) {
                        if (this.delayAmount <= 0) {
                            return;
                        }

                        this.delayAmount--;

                        new ChatManagementMenu(this.playerMenuUtil, this.delayAmount).open(player);
                    } else if (event.getClick().isShiftClick()) {
                        this.main.getChatManager().slowChat(player, this.delayAmount);
                    }

                    break;
                case GLASS:
                    this.main.getChatManager().clearChat(player);

                    break;
            }
        }
    }

    @Override
    public void setMenuItems(Player player) {
        ItemStackButton muteChatItemStackButton = new ItemStackButton(
                ColorUtils.getMessageType("&bToggle Chat"),
                ColorUtils.getMessageType(
                        Arrays.asList(
                                "&fMuted: " + (this.main.getChatManager().isMuted() ? "&aYes" : "&4No"),
                                "&fToggled By: &b" + (this.main.getChatManager().getToggledBy() == null ? "None" : this.main.getServer().getOfflinePlayer(this.main.getChatManager().getToggledBy()).getName()),
                                "&fLast Toggled: &b" + (this.main.getChatManager().getLastToggledTime() == 0 ? "Never" : Utils.getTimeAsAString(this.main.getChatManager().getLastToggledTime())),
                                "",
                                "&bClick to mute the chat"
                        )
                ),
                Material.DIAMOND_SWORD,
                0,
                1
        );

        ItemStackButton slowChatItemStackButton = new ItemStackButton(
                ColorUtils.getMessageType("&bSlow Chat"),
                ColorUtils.getMessageType(
                        Arrays.asList(
                                "&fDelay Amount: &b" + this.main.getChatManager().getDelayAmount(),
                                "&fSlowed By: &b" + (this.main.getChatManager().getSlowedBy() == null ? "None" : this.main.getServer().getOfflinePlayer(this.main.getChatManager().getSlowedBy()).getName()),
                                "&fLast Slowed: &b" + (this.main.getChatManager().getLastSlowedTime() == 0 ? "Never" : Utils.getTimeAsAString(this.main.getChatManager().getLastSlowedTime())),
                                "",
                                "&bShift click to slow the chat for &3" + (this.delayAmount + "second" + (this.delayAmount > 1 ? "s" : "")),
                                "",
                                "&fLeft Click: &b+1",
                                "&fRight Click: &b-1"
                        )
                ),
                Material.SOUL_SAND,
                0,
                1
        );

        ItemStackButton clearChatItemStackButton = new ItemStackButton(
                ColorUtils.getMessageType("&bClear Chat"),
                ColorUtils.getMessageType(
                        Arrays.asList(
                                "&fCleared By: &b" + (this.main.getChatManager().getClearedBy() == null ? "None" : this.main.getServer().getOfflinePlayer(this.main.getChatManager().getClearedBy()).getName()),
                                "&fLast Cleared: &b" + (this.main.getChatManager().getLastClearedTime() == 0 ? "Never" : Utils.getTimeAsAString(this.main.getChatManager().getLastClearedTime())),
                                "",
                                "&bClick to clear the chat"
                        )
                ),
                Material.GLASS,
                0,
                1
        );

        ItemStack muteChatItemStack = muteChatItemStackButton.makeItemStack();
        ItemStack slowChatItemStack = slowChatItemStackButton.makeItemStack();
        ItemStack clearChatItemStack = clearChatItemStackButton.makeItemStack();

        this.setFillerGlass();
        this.inventory.setItem(11, muteChatItemStack);
        this.inventory.setItem(13, slowChatItemStack);
        this.inventory.setItem(15, clearChatItemStack);
    }
}
